## How to contribute to Xpra

#### **Did you find a bug?**

Before creating a new ticket, please:
* For security issues, [contact us](docs/SECURITY.md)

* [search for similar issues](https://github.com/Xpra-org/xpra/issues)

* Take a moment to read the [bug reporting guidelines](https://github.com/Xpra-org/xpra/wiki/Reporting-Bugs)


#### **Did you write a patch that fixes a bug?**

* Open a new GitHub pull request with the patch.

* Ensure the PR description clearly describes the problem and solution.

#### **Do you have questions about the source code?**

The best places are the #xpra IRC channel on [libera.chat](https://libera.chat/) and the [discord channel](https://discord.gg/2mtC6cDv6Q).

Alternatively, you can create a [github discussion](https://github.com/Xpra-org/xpra/discussions).
